pub unsafe extern "C" fn sceGxmDisplayQueueAddEntry(
oldBuffer: *mut SceGxmSyncObject,
newBuffer: *mut SceGxmSyncObject,
callbackData: *const c_void,
) -> c_intExpand description
Add a new display swap request to the display queue.
@param[in] oldBuffer - Synchronization object associated to the previous frame buffer. @param[in] newBuffer - Synchronization object associated to the new incoming frame buffer. @param[in] callbackData - Data to send to the display swap callback.
@return 0 on success, < 0 on error.